@@ -1,7 +1,11 @@
 //! Tactics for Logical OR.
 
+#![allow(unreachable_code)]
+
 use crate::*;
 
+pub use commute as symmetry;
+
 /// `a ∨ b => b ∨ a`.
 pub fn commute<A: Prop, B: Prop>(or: Or<A, B>) -> Or<B, A> {
     use Either::*;
